qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [PATCH v10 7/7] xfs: disable map_sync for async flush


From: Pankaj Gupta
Subject: [Qemu-devel] [PATCH v10 7/7] xfs: disable map_sync for async flush
Date: Tue, 21 May 2019 19:07:13 +0530

Dont support 'MAP_SYNC' with non-DAX files and DAX files
with asynchronous dax_device. Virtio pmem provides
asynchronous host page cache flush mechanism. We don't
support 'MAP_SYNC' with virtio pmem and xfs.

Signed-off-by: Pankaj Gupta <address@hidden>
Reviewed-by: Darrick J. Wong <address@hidden>
---
 fs/xfs/xfs_file.c | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/fs/xfs/xfs_file.c b/fs/xfs/xfs_file.c
index a7ceae90110e..f17652cca5ff 100644
--- a/fs/xfs/xfs_file.c
+++ b/fs/xfs/xfs_file.c
@@ -1203,11 +1203,14 @@ xfs_file_mmap(
        struct file     *filp,
        struct vm_area_struct *vma)
 {
+       struct dax_device       *dax_dev;
+
+       dax_dev = xfs_find_daxdev_for_inode(file_inode(filp));
        /*
         * We don't support synchronous mappings for non-DAX files. At least
         * until someone comes with a sensible use case.
         */
-       if (!IS_DAX(file_inode(filp)) && (vma->vm_flags & VM_SYNC))
+       if (!daxdev_mapping_supported(vma, dax_dev))
                return -EOPNOTSUPP;
 
        file_accessed(filp);
@@ -1203,11 +1203,14 @@ xfs_file_mmap(
        /*
-        * We don't support synchronous mappings for non-DAX files. At least
-        * until someone comes with a sensible use case.
+        * We don't support synchronous mappings for non-DAX files and
+        * for DAX files if underneath dax_device is not synchronous.
         */
-- 
2.20.1




reply via email to

[Prev in Thread] Current Thread [Next in Thread]